@@ -3,8 +3,6 @@
 ################################
 "dialog.between" <- function(show, history)
 {
-	op=options()
-	options(warn=-1)
 #
 # Main dialog window with title
 #
@@ -27,7 +25,7 @@
 	TFrame <- tkframe(tt, relief="groove")
 	labh <- tklabel(TFrame, bitmap="questhead")
 	tkgrid(tklabel(TFrame,text="Between analysis", font="Times 18", foreground="red"), labh)
-	tkbind(labh, "<Button-1>", function() print(help("between")))
+	tkbind(labh, "<Button-1>", function() print(help("bca")))
 	tkgrid(TFrame)
 #
 # Input and output dudis
@@ -98,7 +96,7 @@
 	#
 	# Make the command line
 	#
-		substitute(between(dudi = dudi, fac = fac, scannf = scannf, nf = nf))
+		substitute(bca(x = dudi, fac = fac, scannf = scannf, nf = nf))
 	}
 		
 ################################
@@ -137,12 +135,11 @@
 	#
 	# Execute the command
 	#
-#		ade4TkGUIFlag <<- 1
-		assign("ade4TkGUIFlag", 1, envir=.GlobalEnv)
+		assign("ade4TkGUIFlag", 1, envir=env_ade4tkgui)
 		mydudi <- eval.parent(cmd)
-		assign(eval(dudiname), mydudi, pos=1)
+		assign(eval(dudiname), mydudi, envir=env_ade4tkgui)
 		dialog.dudi.display(show, history, eval(dudiname))
-		rm("ade4TkGUIFlag", envir=.GlobalEnv)
+		rm("ade4TkGUIFlag", envir=env_ade4tkgui)
 		if (history) {
 			commande = paste(eval(dudiname), " <- ", deparse(cmd, width.cutoff = 500), sep = "")
 			rewriteHistory(commande)
